/**
 * @file main.c
 * @author Tanguy Cavagna (tanguy.cavagna@etu.hesge.ch)
 * @brief Main file for the electric field exercice
 * @version 0.1
 * @date 2021-07-12
 * 
 * @copyright Copyright (c) 2021
 * 
 */
#include <stdio.h>
#include <stdlib.h>
#include <time.h>
#include <math.h>
#include "gfx/gfx.h"
#include "charge.h"

#define WINDOW_WIDTH 500
#define WINDOW_HEIGHT 500
#define x0 0 // Minimal x of the universe
#define x1 1 // Maximal x of the universe
#define y0 0 // Minimal y of the universe
#define y1 1 // Maximal y of the universe
#define NB_CHARGES 2
#define NB_POINTS 100

int main(void) {
    srand(time(NULL));

    // GFX initialization
    struct gfx_context_t *ctxt = gfx_create("draw", WINDOW_WIDTH, WINDOW_HEIGHT);
    if (!ctxt) {
        fprintf(stderr, "Graphics initialization failed !\n");
        return EXIT_FAILURE;
    }

    charge_t charges[NB_CHARGES];
    charges[0] = charge_create(10, init_vector(0.25, 0.5));
    charges[1] = charge_create(-10, init_vector(0.75, 0.5));
    draw_charges(ctxt, charges, NB_CHARGES, x0, x1, y0, y1);

    vec2 points[NB_POINTS];
    generate_points(points, NB_POINTS);
    for (int i = 0; i < NB_POINTS; i++) {
        coordinates_t c = position_to_coordinates(WINDOW_WIDTH, WINDOW_HEIGHT, x0, x1, y0, y1, points[i]);
        gfx_putpixel(ctxt, c.column, c.row, COLOR_WHITE);
    }    

    // GFX Draw loop
    while (gfx_keypressed() != SDLK_ESCAPE){
        gfx_present(ctxt);
    }

    gfx_destroy(ctxt);

    return EXIT_SUCCESS;
}