// cmocka includes
#include <stdarg.h>
#include <stddef.h>
#include <setjmp.h>
#include <stdint.h>
#include <cmocka.h>

// vector include
#include <stdio.h>
#include <stdbool.h>
#include "vector.h"

//* ====================
//* Tests descriptions
//* ====================
static void vector_initialization() {
    vec2 v = {2, 3};

    assert_non_null(&v);
}

static void vector_addition() {
    vec2 v1 = {2, 5};
    vec2 v2 = {3, 7};
    vec2 v3;

    vec2 target = {5, 12};

    v3 = add_vector(v1, v2);

    assert_memory_equal(&v3, &target, sizeof(target));
}

static void vector_substraction() {
    vec2 v1 = {2, 5};
    vec2 v2 = {3, 7};
    vec2 v3;

    vec2 target = {-1, -2};

    v3 = sub_vector(v1, v2);

    assert_memory_equal(&v3, &target, sizeof(target));
}

static void vector_multiplication_scalar() {
    vec2 v1 = {2, 5};
    int scal = 2;
    vec2 v2;

    vec2 target = {4, 10};

    v2 = mult_by_scalar(v1, scal);

    assert_memory_equal(&v2, &target, sizeof(target));
}

static void vector_to_polar_convertion() {
    vec2 c_v = {84.85, -84.85};
    polarVector p_v;

    polarVector target = {119.996, -45};

    p_v  = to_polar(c_v);

    assert_float_equal(p_v.a, target.a, 1e-3);
    assert_float_equal(p_v.f, target.f, 1e-3);
}

static void vector_to_cartesian_convertion() {
    polarVector p_v = {200, 60};
    vec2 c_v;

    vec2 target = {100, 173.205};

    c_v = to_cartesian(p_v);

    assert_float_equal(c_v.x, target.x, 1e-3);
    assert_float_equal(c_v.y, target.y, 1e-3);
}

//* ====================
//* Run test
//* ====================
int main(void) {
    const struct CMUnitTest tests[] = {
        cmocka_unit_test(vector_initialization),
        cmocka_unit_test(vector_addition),
        cmocka_unit_test(vector_substraction),
        cmocka_unit_test(vector_multiplication_scalar),
        cmocka_unit_test(vector_to_polar_convertion),
        cmocka_unit_test(vector_to_cartesian_convertion),
    };

    return cmocka_run_group_tests(tests, NULL, NULL);
}