/*! \file Abstract of the vector-lib file
          Contains the skeleton of the vector-lib file. All the functions and structs are defined here.
*/

#ifndef VECTOR_H_ /* Header guard. Prevent the error of double inclusion inside a program. See : https://fr.wikipedia.org/wiki/Include_guard */
#define VECTOR_H_

/**
 * @brief Cartesian vector
 */
typedef struct {
    double x;
    double y;
} vec2;

/**
 * @brief Polar vector used for representation only
 */
typedef struct {
    double f; /* Force of the vector */
    double a; /* Angle of the vector */
} polarVector;

vec2 init_vector(double x, double y); /* Initialize a new vector */
vec2 add_vector(vec2 v1, vec2 v2); /* Add a vector to another and return the result as a vector */
vec2 sub_vector(vec2 v1, vec2 v2); /* Substract a vector to another vector and return the result as a vector */
vec2 mult_by_scalar(vec2 v1, int scalar); /* Multiply a vector by a scalar */
double dot_multiply(vec2 v1, vec2 v2); /* Multiply two vectors with the dot product formula */
double norm(vec2 v1); /* Get the norm of a given vector */
polarVector to_polar(vec2 v1); /* Convert a Cartesian vector to a Polar vector */
vec2 to_cartesian(polarVector v1); /* Convert a Polar vector to a Cartesian vector */

/* For the moment, the cross product hasn't be inplemented because it only work with vectors on 3 dimentionals plan. */

#endif /* VECTOR_H_ */
